@@ -2,6 +2,7 @@ import abml_helpers
 from abaqusConstants import THREE_D, DEFORMABLE_BODY, XZPLANE  # noqa
 from abaqusConstants import XYPLANE, YZPLANE, XZPLANE  # noqa
 from abaqusConstants import MIDDLE_SURFACE, FROM_SECTION  # noqa
+from abaqusConstants import ON, OFF, STANDALONE  # noqa
 from regionToolset import Region
 from abml_dataclass import Abml_Registry
 from abml_dataclass import to_object_option_mode, to_object_key_mode, to_object_cmd_mode
@@ -13,6 +14,51 @@ from abaqus import mdb
 
 @Abml_Registry.register("parts")
 class Abml_Part:
+    """
+    A class representing a part in an Abaqus/Explicit model.
+
+    Parameters
+    ----------
+    name : str
+        The name of the part.
+    model : :ref:`Abml_Model <Abml_Model>`
+        The parent model to which the part belongs.
+    **kwargs
+        Additional keyword arguments that specify the geometry, planes, partitions,
+        surfaces, sets, section assignments, and mesh associated with the part.
+
+    Attributes
+    ----------
+    model : :ref:`Abml_Model <Abml_Model>`
+        The parent model to which the part belongs.
+    name : str
+        The name of the part.
+    geometry : abaqus.geom.GeometryObject or None
+        The geometry object associated with the part, if any.
+    planes : abaqus.core.AbaqusDict or None
+        The planes associated with the part, if any.
+    partitions : abaqus.core.AbaqusDict or None
+        The partitions associated with the part, if any.
+    surfaces : abaqus.core.AbaqusDict or None
+        The surfaces associated with the part, if any.
+    sets : abaqus.core.AbaqusDict or None
+        The sets associated with the part, if any.
+    section_assignments : abaqus.core.AbaqusDict or None
+        The section assignments associated with the part, if any.
+    mesh : abaqus.core.AbaqusDict or None
+        The mesh associated with the part, if any.
+
+    Methods
+    -------
+    create()
+        Creates the part in the model.
+    get_sequence_from_set_list(set_list)
+        Returns a dictionary of sequences of faces, cells, and edges for the specified sets.
+    generate_mesh()
+        Generates the mesh for the part.
+
+    """
+
     def __init__(self, name, model, **kwargs):  # noqa
         self.model = model
         self.name = name
@@ -124,18 +170,55 @@ class Abml_Part:
 
 @Abml_Registry.register("geometry")
 class Abml_Geometry(Abml_Helpers):
-    def __init__(self, type, sketch, part, **kwargs):  # noqa
+    """
+    A class for creating geometries in Abaqus/CAE.
+
+    Parameters
+    ----------
+    type : str
+        | The type of geometry to create. Possible values are
+        | solid_extrusion
+        | solid_revolve
+    sketch : dict
+        A dictionary containing the data for the sketch to create the geometry.
+    part : Part object
+        The part in which to create the geometry.
+    **kwargs
+        Additional keyword arguments to pass to the geometry creation function.
+
+    Methods
+    -------
+    create()
+        Creates the geometry using the appropriate creation function based on the specified type.
+
+    Notes
+    -----
+    This class is intended to be used with the Abaqus finite element analysis software.
+
+    Examples
+    --------
+    part_1:
+      geometry:
+        type: solid_extrusion
+        sketch:
+          - rect:
+            p1: [0.0, 0.0]
+            p2: [1.0, 1.0]
+        depth: 1.0
+    """
+
+    def __init__(self, type, part, **kwargs):  # noqa
         self.type = type
         self.part = part
         self.model = part.model
-
-        params = {"data": sketch, "type_": "sketch", "model": self.model}
-
+        self.kwargs = kwargs
+        self.sketch_name = self.kwargs.get("sketch_name", "__profile__")
+        params = {"data": kwargs.get("sketch", []), "type_": "sketch", "model": self.model, "name": self.sketch_name}
         self.sketch = to_object_cmd_mode(**params)
 
-        self.kwargs = kwargs
         self.map = {
             ("3d", "deformable", "solid_extrusion"): self._create_solid_extrusion,
+            ("3d", "deformable", "solid_revolve"): self._create_solid_revolve,
         }
 
         self.create()
@@ -148,9 +231,27 @@ class Abml_Geometry(Abml_Helpers):
             error_str = "Extrusion depth for part: {} is no int, float or is 0".format(self.part.name)
             raise ValueError(error_str)
         part = self.model.p[self.part.name]
-        sketch = self.model.m.sketches["__profile__"]
+        sketch = self.model.m.sketches[self.sketch_name]
         part.BaseSolidExtrude(depth=self.kwargs["depth"], sketch=sketch)
-        del sketch
+
+        if "__profile__" in self.model.m.sketches:
+            del self.model.m.sketches["__profile__"]
+
+        self.aliases = {}
+
+    def _create_solid_revolve(self):
+        self.sketch[0].create_construction_line()
+        if not isinstance(self.kwargs["angle"], (int, float)) or self.kwargs["angle"] == 0.0:
+            error_str = "Revolve angle for part: {} is no int, float or is 0".format(self.part.name)
+            raise ValueError(error_str)
+        part = self.model.p[self.part.name]
+        sketch = self.model.m.sketches[self.sketch_name]
+
+        part.BaseSolidRevolve(angle=self.kwargs["angle"], sketch=sketch, flipRevolveDirection=OFF)
+        del mdb.models["m1"].sketches[self.sketch_name]
+
+        if "__profile__" in self.model.m.sketches:
+            del self.model.m.sketches["__profile__"]
 
         self.aliases = {}
 
@@ -252,6 +353,47 @@ class Abml_Geometry(Abml_Helpers):
 
 @Abml_Registry.register("planes")
 class Abml_Plane:
+    """
+    A class to create datum planes in Abaqus.
+
+    Parameters
+    ----------
+    name : str
+        The name of the datum plane to be created.
+    part : Abml_Part
+        The Abml_Part object to which the datum plane belongs.
+    **kwargs : dict
+        Additional keyword arguments to be passed to the Abaqus API. The keys of the dictionary should be the names of
+        the principal planes ('x', 'y', or 'z'), and the values should be the offsets of the datum planes from the
+        origin in the corresponding directions.
+
+    Attributes
+    ----------
+    name : str
+        The name of the datum plane.
+    part : Abml_Part
+        The Abml_Part object to which the datum plane belongs.
+    model : Abml_Model
+        The Abml_Model object to which the datum plane belongs.
+    kwargs : dict
+        The keyword arguments passed to the Abaqus API.
+    _principal_Plane : dict
+        A dictionary mapping the names of the principal planes ('x', 'y', or 'z') to the corresponding constants in
+        the Abaqus API.
+
+    Methods
+    -------
+    create()
+        Create the datum plane in the Abaqus model.
+
+    Notes
+    -----
+    This class uses the Abaqus API to create datum planes in Abaqus. The datum planes are created in the part
+    specified by the `part` parameter. The position and orientation of the datum planes are specified by the
+    `**kwargs` parameter. The keys of the `**kwargs` parameter should be the names of the principal planes ('x', 'y',
+    or 'z'), and the values should be the offsets of the datum planes from the origin in the corresponding directions.
+    """
+
     def __init__(self, name, part, **kwargs):  # noqa
         self.name = name
         self.part = part
@@ -270,6 +412,53 @@ class Abml_Plane:
 
 @Abml_Registry.register("partitions")
 class Abml_Partition(Abml_Helpers):
+    """
+    A class for partitioning parts in Abaqus based on faces, edges, and cells.
+
+    Parameters
+    ----------
+    part : abaqus Part object
+        The part to be partitioned.
+    faces : list of ints, optional
+        A list of face IDs to be partitioned. Defaults to None.
+    edges : list of ints, optional
+        A list of edge IDs to be partitioned. Defaults to None.
+    cells : list of ints, optional
+        A list of cell IDs to be partitioned. Defaults to None.
+    **kwargs : dict
+        Optional keyword arguments to be passed to the partitioning function. The supported
+        keys are 'cmd' (str) and 'planes' (list of str). 'cmd' specifies the partitioning
+        method to use, and 'planes' is a list of datum plane feature IDs.
+
+    Attributes
+    ----------
+    method : str
+        The partitioning method to use.
+    part : abaqus Part object
+        The part to be partitioned.
+    model : abaqus Model object
+        The model containing the part to be partitioned.
+    faces : list of lists of ints or str
+        A list of face IDs to be partitioned. If None, no faces are partitioned.
+    edges : list of lists of ints or str
+        A list of edge IDs to be partitioned. If None, no edges are partitioned.
+    cells : list of lists of ints or str
+        A list of cell IDs to be partitioned. If None, no cells are partitioned.
+    kwargs : dict
+        Optional keyword arguments passed to the partitioning function.
+    partition_map : dict
+        A dictionary containing the partitioning method names and their corresponding
+        partitioning functions.
+
+    Methods
+    -------
+    create()
+        Calls the partitioning function specified by 'method'.
+    create_face_plane()
+        Partitions the faces of the part by a datum plane.
+
+    """
+
     def __init__(self, part, faces=None, edges=None, cells=None, **kwargs):
         self.method = kwargs.get("cmd", "plane")
         self.part = part
